biomass: Calculating biomass by species by life stage for each year

Description Usage Arguments Value

View source: R/biomass.R

Description

Calculating biomass by species by life stage for each year

Usage

1
biomass(data, Species, Stage, Year, Mass)

Arguments

data

data.frame to use

Species

first column to group by

Stage

second column to group by

Year

third column to group by

Mass

column that is summed

Value

data frame with biomass for each life stage of a species for each year


brittanymaldonado/maldonadopackage documentation built on Dec. 31, 2020, 8:58 p.m.